==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/AuthenticationStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AuthenticationStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus,io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusBuilder>{
  public AuthenticationStatusBuilder() {
    this(false);
  }
  public AuthenticationStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new AuthenticationStatus(), validationEnabled);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AuthenticationStatus(), validationEnabled);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus instance) {
    this(fluent, instance, false);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withOauthAPIServer(instance.getOauthAPIServer()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus instance) {
    this(instance,false);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withOauthAPIServer(instance.getOauthAPIServer()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus build() {
    AuthenticationStatus buildable = new AuthenticationStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getOauthAPIServer(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthenticationStatusBuilder that = (AuthenticationStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/AuthenticationStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AuthenticationStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus,io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusBuilder>{
  public AuthenticationStatusBuilder() {
    this(false);
  }
  public AuthenticationStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new AuthenticationStatus(), validationEnabled);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AuthenticationStatus(), validationEnabled);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus instance) {
    this(fluent, instance, false);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withOauthAPIServer(instance.getOauthAPIServer()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus instance) {
    this(instance,false);
  }
  public AuthenticationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withOauthAPIServer(instance.getOauthAPIServer()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.AuthenticationStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.AuthenticationStatus build() {
    AuthenticationStatus buildable = new AuthenticationStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getOauthAPIServer(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthenticationStatusBuilder that = (AuthenticationStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
